@@ -153,6 +153,8 @@ def main():
                 kwargs['hash'] = hashes[0]
             if options['format'] is not None:
                 kwargs['format'] = options['format']
+            if options['url'] is not None:
+                kwargs['url'] = options['url']
 
             wfapi.report(**kwargs)
             print_status(wfapi, action)
@@ -164,6 +166,7 @@ def main():
             if len(hashes) == 1:
                 action = 'verdict'
                 kwargs['hash'] = hashes[0]
+                kwargs['url'] = options['url']
                 wfapi.verdict(**kwargs)
             elif len(hashes) > 1:
                 action = 'verdicts'
@@ -171,6 +174,7 @@ def main():
                 wfapi.verdicts(**kwargs)
             else:
                 action = 'verdict'
+                kwargs['url'] = options['url']
                 wfapi.verdict(**kwargs)
 
             print_status(wfapi, action)
@@ -230,10 +234,30 @@ def main():
             print_response(wfapi, options)
             save_file(wfapi, options)
 
+        if options['web-artifacts']:
+            action = 'web-artifacts'
+            kwargs = {}
+            if options['url'] is not None:
+                kwargs['url'] = options['url']
+            if len(options['types']):
+                kwargs['types'] = ','.join(options['types'])
+
+            wfapi.web_artifacts(**kwargs)
+            print_status(wfapi, action)
+            print_response(wfapi, options)
+            save_file(wfapi, options)
+
         if options['testfile']:
             action = 'testfile'
 
-            wfapi.testfile(options['type'])
+            if len(options['types']) > 1:
+                print('Only 1 type allowed for %s' % action, file=sys.stderr)
+                sys.exit(1)
+
+            kwargs = {}
+            if len(options['types']) == 1:
+                kwargs['file_type'] = options['types'][0]
+            wfapi.testfile(**kwargs)
             print_status(wfapi, action)
             print_response(wfapi, options)
             save_file(wfapi, options)
@@ -313,6 +337,7 @@ def process_verdict(verdict):
         'malware': pan.wfapi.MALWARE,
         'grayware': pan.wfapi.GRAYWARE,
         'phishing': pan.wfapi.PHISHING,
+        # XXX C2?
     }
 
     try:
@@ -334,13 +359,15 @@ def parse_opts():
         'sample': False,
         'pcap': False,
         'changed': False,
+        'web-artifacts': False,
         'hash': [],
+        'url': None,
         'platform': None,
         'new-verdict': None,
         'email': None,
         'comment': None,
         'testfile': False,
-        'type': None,
+        'types': [],
         'format': None,
         'date': None,
         'dst': None,
@@ -357,14 +384,14 @@ def parse_opts():
         'debug': 0,
         'tag': None,
         'timeout': None,
-        }
+    }
 
     short_options = 'K:h:xpjHDt:T:'
     long_options = ['version', 'help',
                     'submit=', 'submit-link=',
                     'change-request', 'report', 'verdict', 'sample',
-                    'pcap', 'changed',
-                    'hash=', 'platform=', 'testfile',
+                    'pcap', 'changed', 'web-artifacts',
+                    'hash=', 'url=', 'platform=', 'testfile',
                     'new-verdict=', 'email=', 'comment=',
                     'type=', 'format=', 'date=', 'dst=',
                     'http', 'ssl=', 'cafile=', 'capath=',
@@ -397,8 +424,12 @@ def parse_opts():
             options['pcap'] = True
         elif opt == '--changed':
             options['changed'] = True
+        elif opt == '--web-artifacts':
+            options['web-artifacts'] = True
         elif opt == '--hash':
             options['hash'].append(arg)
+        elif opt == '--url':
+            options['url'] = arg
         elif opt == '--platform':
             options['platform'] = arg
         elif opt == '--new-verdict':
@@ -410,7 +441,7 @@ def parse_opts():
         elif opt == '--testfile':
             options['testfile'] = True
         elif opt == '--type':
-            options['type'] = arg
+            options['types'].append(arg)
         elif opt == '--format':
             options['format'] = arg
         elif opt == '--date':
@@ -526,6 +557,32 @@ def print_response(wfapi, options):
         if options['print_html']:
             print(wfapi.response_body.rstrip())
 
+    elif wfapi.response_type == 'json' and wfapi.response_body is not None:
+        if options['print_json'] or options['print_python']:
+            try:
+                d = json.loads(wfapi.response_body)
+            except ValueError as e:
+                print('Invalid JSON: %s' % e, file=sys.stderr)
+                print(wfapi.response_body.rstrip())
+                return
+
+            try:
+                report_str = d['result']['report']
+            except KeyError:
+                pass
+            else:
+                if report_str:
+                    try:
+                        report_json = json.loads(report_str)
+                    except ValueError as e:
+                        print('Invalid JSON (report): %s' % e, file=sys.stderr)
+                    else:
+                        d['result']['report'] = report_json
+            if options['print_python']:
+                print('var1 =', pprint.pformat(d))
+            if options['print_json']:
+                print(json.dumps(d, sort_keys=True, indent=2))
+
     elif wfapi.response_type == 'xml' and wfapi.response_body is not None:
         if options['print_xml']:
             print(wfapi.response_body.rstrip())
@@ -619,13 +676,15 @@ def usage():
     --sample              get WildFire sample file
     --pcap                get WildFire PCAP files
     --changed             get changed verdicts
+    --web-artifacts       get WildFire URL web artifacts
     --hash hash           query MD5 or SHA256 hash
+    --url url             query URL
     --platform id         platform ID for sandbox environment
     --new-verdict verdict benign|malware|grayware|phishing
     --email address       notification e-mail address
     --comment comment     change request explanation
     --testfile            get sample malware test file
-    --type type           test file type
+    --type type           test file or web artifact type
     --format format       report output format
     --date date           start date for changed verdicts
                           (YYYY-MM-DD or -days)
@@ -633,8 +692,8 @@ def usage():
     -K api_key            WildFire API key
     -h hostname           WildFire hostname
     -x                    print XML response to stdout
-    -p                    print XML response in Python to stdout
-    -j                    print XML response in JSON to stdout
+    -p                    print XML and JSON response in Python to stdout
+    -j                    print XML and JSON response in JSON to stdout
     -D                    enable debug (multiple up to -DDD)
     -t tag                .panrc tagname
     -T seconds            urlopen() timeout
